/**
 * Name    : controller
 * Purpose : contains callbacks for application routes.
 * Params  : --
 * Returns : --
 **/
;
(function() {
    App.controller = {
        /**
         * Name    : initialize
         * Purpose : initializes the application controller and performs bootstrap operations.
         * Params  : --
         * Returns : --
         **/
        initialize: function() {
            console.log('METHOD : App Controller initialize');
            var _this = this;
            App.bind('start', function(options) {
                // Operations to be performed immediately after app start.
            });
        },
        /**
         * Name    : checkNetwork
         * Purpose : Alerts the user of network failure.
         * Params  : --
         * Returns : --
         **/
        checkNetwork: function() {
            App.controller.showSecondPopup("alert", {
                title: "No Network Connectivity !!",
                subject:"" ,
                message: ""
            });
        },
        /**
         * Name    : beforeRoute
         * Purpose : initializes the application controller and performs bootstrap operations.
         * Params  : route - the url to navigate, args object containing e - event object, name - route name
         * Returns : --
         **/
        beforeRoute: function(route, args) {
            console.log('METHOD : App Controller beforeRoute start');
            window.scrollTo(0, 0);
            var r;
            for (r in App.regions) {
                if (App.regions.hasOwnProperty(r)) {
                    if (!App.regions[r].permanent) {
                        if (App.regions[r]) {
                            App.regions[r].close();
                        }
                    }
                }
            }
        },
        /**
         * Name    : loadPage
         * Purpose : loads the view into the dom (region).
         * Params  : layoutName - Layout to be loaded, viewName - view name if body id should be similar to view name rather than layout name else null, options object to be passed to the view, region -
         * Returns : --
         **/
        loadPage: function(layoutName, viewName, options) {
            console.log('METHOD : App Controller loadPage');
            App.events.closeSecondPopups();
            var view;
         
            if (viewName) {
                App.applyBodyID(viewName);
                App.sessionVars.currentPage = viewName;
            } else {
                App.applyBodyID(layoutName);
                App.sessionVars.currentPage = layoutName;
            }
            if (layoutName) {
                App.pages[layoutName] = new app.pages[layoutName](options);
                view = App.pages[layoutName];
            } else {
                App.views[viewName] = new app.views[viewName](options);
                view = App.views[viewName];
            }
            if (App.pages.footer) {
                App.pages.footer.updateFooter();
            }
            App.regions.body.show(view);
            App.events.pageLoad();
        },
        /**
         * Name    : onPageLoad
         * Purpose : Gets called after an individual page has been loaded. For the time being this just sets the bodyHeight
         * Params  : e - the event that triggered the new page load. If none, the value of e is undefined
         * Returns : --
         **/
        onPageLoad: function(e) {
            App.controller.setBodyHeight();
        },
        /**
         * Name    : showPopup
         * Purpose : Shows alerts, confirm or any other view in a popup style.
         * Params  : viewName - name of the view to be shown as popup, options - object containing specfics of the popup(like callback etc..), layoutName - the layout name which may contain the popup.
         * Returns : --
         **/
        showPopup: function(viewName, options, layoutName) {
        	//$('#bodyRegion').css('overflow','hidden');
        	
            console.log('METHOD : App Controller showPopup');
            options = options || {};
            
            if (viewName) {
                popup = new app.views[viewName](options);
                App.regions.popup.show(popup);
            } else {
                popup = new app.pages[layoutName](options);
                App.regions.popup.show(popup);
            }
            App.controller.setMaskHeight();
            $("#popupRegionMask").addClass("mask_active_h");
            $("#popupRegion").show();
            $("#popupRegionMask").show();
            //$("#popupRegionMask").css('position','fixed');
            
			if(App.settings.deviceWidth>602 && App.sessionVars.currentPage == "userLogin" && viewName == "loader"){
            	App.regions.popup.$el.find('.loader_con_h').css('left','50%');
            }
            //$("#bodyHeightRegion").css("position","fixed");
           	if(App.session.device.iOS){
            	App.regions.popup.$el.find('.popup_outer').addClass('ios');
            }
            
           $('#bodyRegion').removeClass('bodyRegion-touch');
           $('#bodyRegion').addClass('bodyRegion');
           if (!(navigator.userAgent.toLocaleLowerCase().indexOf('android') != -1))
           {
                $('#headerRegion').removeClass('fixed');
                $('#headerRegion').css('position' ,'absolute');
           }
           $('#popupRegionMask').height($('#popupRegion').height());
        },
        
        /**
         * Name    : showSecondPopup
         * Purpose : Shows alerts, confirm or any other view in a popup style.
         * Params  : viewName - name of the view to be shown as popup, options - object containing specfics of the popup(like callback etc..), layoutName - the layout name which may contain the popup.
         * Returns : --
         **/
        showSecondPopup: function(viewName, options, layoutName) {
        	
            $('#bodyRegion').removeClass('bodyRegion-touch');
            $('#bodyRegion').addClass('bodyRegion');          

            if (!(navigator.userAgent.toLocaleLowerCase().indexOf('android') != -1))
            {
                $('#headerRegion').removeClass('fixed');
                $('#headerRegion').css('position' ,'absolute');
            }     

            //$('#bodyRegion').css('overflow','hidden');
            console.log('METHOD : App Controller showSecondPopup');
            options = options || {};
            
            if (viewName) {
                popup = new app.views[viewName](options);
                App.regions.popupSecond.show(popup);
            } else {
                popup = new app.pages[layoutName](options);
                App.regions.popupSecond.show(popup);
            }
            if(!($('#popupRegionMask').hasClass('mask_active_h'))){
            	App.controller.setMaskHeight();
            }
            $("#popupRegionMaskSecond").addClass("mask_active_h");
            $("#popupRegionSecond").show();
            $("#popupRegionMaskSecond").show();
            $('#popupRegionSecond').bind('touchmove', function(e){e.preventDefault()});
            $(document).scrollTop(0);
           	// $("#popupRegionMaskSecond").css('position','fixed');
           	// $("#bodyHeightRegion").css("position","fixed");
			if(App.settings.deviceWidth>602 && App.sessionVars.currentPage == "userLogin" && viewName == "loader"){
            	App.regions.popupSecond.$el.find('.loader_con_h').css('left','50%');
            }

            if(App.session.device.iOS && App.regions.popupSecond.$el.find('.popup_outer')){
            	App.regions.popupSecond.$el.find('.popup_outer').addClass('ios');
            }

            $('#popupRegionMask').height($('#popupRegion').height());
        },
        
        
        /**
         * Name    : popupsClose
         * Purpose : Close all popups.
         * Params  : --
         * Returns : --
         **/
        popupsClose: function() {     
            $('#bodyRegion').removeClass('bodyRegion');
            $('#bodyRegion').addClass('bodyRegion-touch');            
           $('#headerRegion').addClass('fixed');

            console.log('METHOD : App Controller popupsClose');
            var bodyId = $('body').attr('id');
            $('#bodyRegion').css('overflow-y','');
            $('#bodyRegion').css('overflow-x','');
            App.controller.setBodyHeight();
            $('#bodyHeightRegion').css({
                'pointer-events': '',
                'overflow': 'auto'
            });
            $('#headerRegion').css({
                'pointer-events': ''
            });
            try {
                App.regions.popup.close();
            } catch (e) {
                console.log("ERROR: CLOSING POPUP: " + e);
            }
			if(App.regions.popup.$el){
            	App.regions.popup.$el.unbind('click');	
            }

            $("#popupRegionMask").removeClass("mask_active_h");
            $("#popupRegion").hide();
            $("#popupRegionMask").hide();
           	$("#bodyHeightRegion").css("position","relative");	
            
            
            
            
        },
        
        /**
         * Name    : secondPopupsClose
         * Purpose : Close all popups.
         * Params  : --
         * Returns : --
         **/
        secondPopupsClose: function() {      
  
            $('#bodyRegion').removeClass('bodyRegion');
            $('#bodyRegion').addClass('bodyRegion-touch');
            $('#headerRegion').addClass('fixed'); 
            console.log('METHOD : App Controller secondPopupsClose');
            if(!($('#popupRegionMask').hasClass('mask_active_h'))){
            	$('#bodyRegion').css('overflow-y','');
                $('#bodyRegion').css('overflow-x','');
            	var bodyId = $('body').attr('id');
	            App.controller.setBodyHeight();
	            $('#bodyHeightRegion').css({
	                'pointer-events': '',
	                'overflow': 'auto'
	            });
	            $('#headerRegion').css({
	                'pointer-events': ''
	            });
            }
            
            try {
                App.regions.popupSecond.close();
            } catch (e) {
                console.log("ERROR: CLOSING POPUP: " + e);
            }
			if(App.regions.popupSecond.$el){
            	App.regions.popupSecond.$el.unbind('click');	
            }

            $("#popupRegionMaskSecond").removeClass("mask_active_h");
            $("#popupRegionSecond").hide();
            $("#popupRegionMaskSecond").hide();
            if(App.regions.popup && App.regions.popup.$el){
            	if(!App.regions.popup.$el.html()){
					$("#bodyHeightRegion").css("position","relative");
            	}

            }
            
        },
        /**
         * Name    : setMaskHeight
         * Purpose : Sets the mask height when the "showPopup" function is called 
         * Params  : --
         * Returns : --
         **/
        setMaskHeight: function() {
            console.log("setMaskHeight");
            var popupHeight = $('#popupRegion').height() + 100;
            var maskHeight = (App.settings.deviceHeight < popupHeight) ? popupHeight : App.settings.deviceHeight;
            var bodyId = $("body").attr('id');
            switch (bodyId) {
                case 'userLogin_Body':
                    
                    break;
               
                default:
                    break;
            }
            $('#headerRegion').css({
                'pointer-events': 'none'
            });
            $('#bodyHeightRegion').css({
                'pointer-events': 'none',
                'overflow': 'hidden'
            });
            var headerHeight = $('#headerRegion').height();
            switch (bodyId) {
            	case "userLogin_Body":
            		$('#bodyRegion').css({'padding-top':'0px'});
            		break;
                default:
                if(App.session.device.iOS){
                	$('#bodyRegion').css({'padding-top':'52px','height':(App.settings.deviceHeight-(headerHeight+22))});
                }else{
                	$('#bodyRegion').css({'padding-top':'42px','height':(App.settings.deviceHeight-(headerHeight))});
                }
                    break;
            }
            
        },
        /**
         * Name    : setBodyHeight
         * Purpose : Sets the body height when the "popupsClose" or "onPageLoad" function is called.
         * Params  : --
         * Returns : --
         **/
        setBodyHeight: function() {
            console.log("setBodyHeight");
            var bodyId = $("body").attr('id');
            var headerHeight = $('#headerRegion').height();
            switch (bodyId) {
            	case "userLogin_Body":
            		$('#bodyRegion').css({'padding-top':'0px','height':(App.settings.deviceHeight)});
            		break;
                default:
                if(App.session.device.iOS){
                	$('#bodyRegion').css({'padding-top':'52px','height':(App.settings.deviceHeight-(headerHeight+22))});
                }else{
                	$('#bodyRegion').css({'padding-top':'42px','height':(App.settings.deviceHeight-(headerHeight))});
                }
                    break;
            }
            
        },
        /**
         * Name    : index
         * Purpose : Route Callback - navigates to the page where user was previously on if logged in else to landing page.
         * Params  : --
         * Returns : --
         **/
        index: function() {
            console.log('METHOD : App Controller index');
            console.log("____language"+App.language);
            

            //ASI chnages

            App.controller.showHome();

           // if(window.localStorage.getItem('userData')!=undefined){
           //  App.controller.showBillBoard();
           // }
           // else
           // {
           //  App.controller.showUserLogin();
           // }
            
            if (App.session.device.android || App.session.device.iOS || App.session.device.windows) {
            	try{
            		navigator.splashscreen.hide();
            	}catch(e){
            		console.log("Error in hiding splash screen.");
            	}
                
            }

        },
        /**
         * Name    : showHeader
         * Purpose : loads the header view in the dom.
         * Params  : --
         * Returns : --
         **/
        showHeader: function() {
            console.log('METHOD : App Controller showHeader');
            App.pages.header = new app.pages.header;
            App.regions.header.show(App.pages.header);
        },
        
        //ASI Functions
            showHome: function() {
            console.log('METHOD : App Controller showHome');
            App.controller.loadPage('homeList', null, null);
        },
                showMonuments: function() {
            console.log('METHOD : App Controller showMonuments');
            App.controller.loadPage('monument', null, null);
        },
                showPilgrims: function() {
            console.log('METHOD : App Controller showPilgrims');
             App.controller.loadPage('pilgrimList', null, null);
        },
                showPlan: function() {
            console.log('METHOD : App Controller showPlan');
             App.controller.loadPage('plan', null, null);
        },
                showItenary: function() {
            console.log('METHOD : App Controller showItenary');            
             App.controller.loadPage('itenaryList', null, null);
        },
                showAbout: function() {
            console.log('METHOD : App Controller showAbout');
             App.controller.loadPage('about', null, null);
        },
            showDetail: function() {
            console.log('METHOD : App Controller showAbout');
             App.controller.loadPage('detail', null, null);
        },
        /**
         * Name    : showMenu
         * Purpose : loads the menu view in the dom.
         * Params  : --
         * Returns : --
         **/
        showMenu: function() {
            console.log('METHOD : App Controller showMenu');
            App.pages.menu = new app.pages.menu;
            App.regions.menu.show(App.pages.menu);
        },
        /**
         * Name    : showFooter
         * Purpose : loads the footer view in the dom.
         * Params  : --
         * Returns : --
         **/
        showFooter: function() {
            App.pages.footer = new app.pages.footer;
            App.regions.footer.show(App.pages.footer);
        },
        /**
         * Name    : backButtonHandler
         * Purpose : customized back button behaviour.
         * Params  : --
         * Returns : --
         **/
        backButtonHandler: function(options){
            console.log('METHOD : App Controller backButtonHandler');
            var manuallyHandled = false;

            if($('#popupRegionMask').hasClass('mask_active_h'))
            {
                App.events.closeSecondPopups();
                manuallyHandled = true;
                console.log("Popup closed on back button firing");
            }
            else if($("#menuRegion").hasClass('menu_shown_h'))
            {
                App.events.hideMenu();
                manuallyHandled = true;
            }
            else
            {
                switch(App.sessionVars.currentPage)
                {
                case "homeList":
                    App.controller.showSecondPopup("confirm", {
                        title : 'You want to exit ??',
                        callBack : function() {
                            if(App.sessionVars.click=="ok")
                            {
                                console.log("exit app");
                                navigator.app.exitApp();
                            }
                        }
                    }, null);
                    manuallyHandled = true;                   
                    break;            
                }
            }
            if (!manuallyHandled) 
            {
                window.history.back();
            }
        }        
    };
})();